@@ -84,7 +84,7 @@
 #define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDNSSD_NO_DEPRECATED
-#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KDNSSD_NO_DEPRECATED_WARNINGS
 #  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
